@@ -137,6 +137,7 @@ class SubSequence {
  * 			12/06/09 Fix 1337 support relative path
  *          18/02/10 Fix 1576 Change email subject
  *			21/07/10 Fix 1660 OutofMemory issue with Biojava
+ *			31/07/12 Fix If out option is used, used outfilename in mail
  *          
  * Known issues in DMR mode: configuration file and model do not support relative path, only sequence path does support it.
  * This issue is due to the fact that when job is transfered on a node, the path is not the same and is system dependent. The software does not change this directory (TODO)
@@ -791,6 +792,10 @@ public class Dispatch {
 	 	    try {
 	 	     String messageTemplate=getEmailTemplate();
 	 	     String message=messageTemplate.replaceAll("__FILE__",bankName+"."+guid+".zip");
+		      if(zipFileName!=null) {
+		    	  File tmpfile = new File(zipFileName);
+		    	  message=messageTemplate.replaceAll("__FILE__",tmpfile.getName());
+		     }
 	 	     if(errMsg.length()>0) {
 	 	    	 message += "ERRORS: \n"+errMsg;
 	 	     }
