@@ -145,8 +145,37 @@ public class GrammarTest {
 			assertTrue(matchNode==null);
 			
 		}
-	 
-	 
+
+		 /**
+		  * Count number of matches.
+		  * @param fileID
+		  * @throws ParserConfigurationException
+		  * @throws SAXException
+		  * @throws IOException
+		  * @throws TransformerException
+		  */
+		private int getNbResult(int fileID) throws ParserConfigurationException, SAXException, IOException, TransformerException {
+			String resFilePath = Logol.getOutputSeqName();
+			
+			File resFile = new File(resFilePath);
+			
+			logger.info("Checking file "+resFilePath);
+			
+			assertTrue(resFile.exists());
+			
+			DocumentBuilder builder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
+			Document document = builder.parse(resFile);
+			String expression=null;
+			
+			
+			expression = "/sequences/match";
+			NodeList matchNode = XPathAPI.selectNodeList(document,expression);
+			int nb = 0;
+			if(matchNode!=null) {
+				nb = matchNode.getLength();
+			}
+			return nb;
+		}
 	 /**
 	  * Checks variable begin and end position based on a Vector of test positions. Only first level of variable node can be tested.
 	  * Sub nodes e.g. sub-variable does cannot be tested by this function.
@@ -621,9 +650,9 @@ public class GrammarTest {
 	 @Test
 	 public void testAmbiguous(){
 		 
-		 assumeTrue(config.getInt("suffix.tool")==0);
-		 
 			init();
+			
+			assumeTrue(config.getInt("suffix.tool")==0);
 		
 			Vector<String[]> result = new Vector<String[]>();
 			result.add(new String[] {"LogolVAR_1","4","7"});
@@ -1149,6 +1178,27 @@ public class GrammarTest {
 			
 	 }	 
 	 
+	 @Test
+	 public void testRepeatAnySpacer(){
+			init();
+			
+			execute("repeat_anyspacer.logol");
+			
+			try {
+				int count = getNbResult(0);
+				assertTrue(count>0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}
+			
+	 }	 
+	 
 	 @Test
 	 public void testReverse(){
 			init();
@@ -1929,4 +1979,49 @@ public class GrammarTest {
 			}			
 		}
 		
+		@Test
+		public void test2244() {
+			
+			init();
+			
+			Vector<String[]> result = null;
+			
+			execute("2244.fasta","2244.logol");
+			
+			try {
+				checkNoMatch(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}			
+		}
+
+		@Test
+		public void test2235() {
+			
+			init();
+			
+			Vector<String[]> result = new Vector<String[]>();
+			result.add(new String[] {"LogolVAR_1","5","16"});
+			
+			execute("2235.fasta","2235.logol");
+			
+			try {
+				checkResult(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}			
+		}
+		
 }
