@@ -38,14 +38,12 @@ import org.apache.commons.cli.Option;
 import org.apache.commons.cli.Options;
 import org.apache.log4j.Logger;
 import org.apache.xpath.XPathAPI;
-import org.biojava.bio.seq.Sequence;
 import org.irisa.genouest.logol.Constants;
 import org.irisa.genouest.logol.Expression;
 import org.irisa.genouest.logol.GrammarException;
 import org.irisa.genouest.logol.LogolVariable;
 import org.irisa.genouest.logol.Treatment;
 import org.irisa.genouest.logol.VariableId;
-import org.irisa.genouest.logol.Entity;
 import org.irisa.genouest.logol.XmlCountHandler;
 import org.irisa.genouest.logol.utils.model.ModelConverter;
 import org.irisa.genouest.logol.utils.model.ModelDefinitionException;
@@ -59,6 +57,7 @@ import org.xml.sax.helpers.DefaultHandler;
  * History:
  * Fix @1796: intermediate variables lost when put in a view
  * 20/06/11 @FIX 1806
+ * 16/03/13 Display number of match per file
  * @author osallou
  *
  */
@@ -809,12 +808,15 @@ public class LogolUtils {
 
 	public static int countMatches(Vector<String> xmlFiles) {
 		int totalCount=0;
-
+        logger.info("**** Results ****");
 	    for(int i=0;i<xmlFiles.size();i++) {
 	        String xmlFile = xmlFiles.get(i);
-	        totalCount = countMatch(xmlFile);     
+	        int count = countMatch(xmlFile);
+	        totalCount += count;
+	        logger.info("*\t"+xmlFile+"\t"+count);
+   
 	    }    
-	     logger.info("Total matches: "+totalCount);
+	     logger.info("****\tTotal matches:\t"+totalCount);
 		 return totalCount;
 	}
 	
